document.addEventListener("DOMContentLoaded", function() {
    // Инициализация intl-tel-input для первой формы
    const phoneInputHero = document.querySelector("#Phone-1");
    const itiHero = window.intlTelInput(phoneInputHero, {
        initialCountry: "auto",
        geoIpLookup: function(callback) {
            fetch('https://ipinfo.io?token=your_token') // Замените 'your_token' на ваш токен
                .then(response => response.json())
                .then(data => callback(data.country))
                .catch(() => callback('us'));
        },
        utilsScript: "https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.0/lib/libphonenumber.js"
    });

    // Функция для обработки отправки формы
    function handleFormSubmit(formId, phoneInput, iti) {
        const form = document.getElementById(formId);
        const successMessage = form.querySelector('.success');
        const errorMessage = form.querySelector('.error');

        form.addEventListener('submit', function(event) {
            event.preventDefault(); // Предотвращаем стандартное поведение формы

            // Скрываем предыдущие сообщения
            successMessage.classList.remove('show');
            errorMessage.classList.remove('show');

            // Собираем данные формы
            const formData = new FormData(form);
            const countryCode = iti.getSelectedCountryData().dialCode; // Получаем код страны
            const phoneNumber = phoneInput.value; // Получаем введенный номер телефона

            // Объединяем код страны и номер телефона
            const fullPhoneNumber = `${countryCode} ${phoneNumber}`;

            // Добавляем объединенный номер телефона в formData
            formData.append("Phone", fullPhoneNumber); // Объединенный номер телефона

            // Отправка AJAX-запроса
            fetch(form.action, {
                method: 'POST',
                body: formData,
            })
            .then(response => response.json()) // Ожидаем JSON-ответ от сервера
            .then(data => {
                if (data.status === 'success') {
                    successMessage.classList.add('show'); // Показываем сообщение об успехе
                    setTimeout(() => {
                        successMessage.classList.remove('show'); // Скрываем через 5 секунд
                    }, 5000);
                    form.reset(); // Сбрасываем поля формы
                } else {
                    errorMessage.classList.add('show'); // Показываем сообщение об ошибке
                    setTimeout(() => {
                        errorMessage.classList.remove('show'); // Скрываем через 5 секунд
                    }, 5000);
                }
            })
            .catch(error => {
                console.error('Ошибка:', error);
                errorMessage.classList.add('show'); // Показываем сообщение об ошибке
                setTimeout(() => {
                    errorMessage.classList.remove('show'); // Скрываем через 5 секунд
                }, 5000);
            });
        });
    }

    // Инициализация intl-tel-input для второй формы
    const phoneInputModal = document.querySelector("#Phone");
    const itiModal = window.intlTelInput(phoneInputModal, {
        initialCountry: "auto",
        geoIpLookup: function(callback) {
            fetch('https://ipinfo.io?token=your_token') // Замените 'your_token' на ваш токен
                .then(response => response.json())
                .then(data => callback(data.country))
                .catch(() => callback('us'));
        },
        utilsScript: "https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.0/lib/libphonenumber.js"
    });

    // Вызываем функцию для каждой формы
    handleFormSubmit('wf-form-Phone-hero', phoneInputHero, itiHero); // Первая форма
    handleFormSubmit('wf-form-Phone-modal', phoneInputModal, itiModal); // Вторая форма
});
