<?php

add_action( 'wp_enqueue_scripts', function () {
    // Подключение стилей
    wp_enqueue_style( 'normalize', get_template_directory_uri() . '/assets/css/normalize.css' );
	wp_enqueue_style( 'webflow', get_template_directory_uri() . '/assets/css/webflow.css' );
	wp_enqueue_style( 'style', get_template_directory_uri() . '/assets/css/dubairent.webflow.css' );
	//wp_enqueue_style( 'custom', get_template_directory_uri() . '/assets/css/custom.css' );
    
    // Подключение скриптов
    wp_enqueue_script('cloudfront-jquery', 'https://d3e54v103j8qbb.cloudfront.net/js/jquery-3.5.1.min.dc5e7f18c8.js?site=651ee211cff32289632fc016', array(), '3.5.1', true);
    wp_script_add_data('cloudfront-jquery', 'integrity', 'sha256-9/aliU8dGd2tb6OSsuzixeV4y/faTqgFtohetphbbj0=');
    wp_script_add_data('cloudfront-jquery', 'crossorigin', 'anonymous');
    wp_enqueue_script('webflow-js', get_template_directory_uri() . '/assets/js/webflow.js', array('cloudfront-jquery'), '1.0', true);
    wp_enqueue_script( 'scripts', get_template_directory_uri() . '/assets/js/telegram.js', array(), 'null', true );
    
});

add_theme_support('post-thumbnails');

// Отключение стандартных размеров изображений WordPress
function disable_default_image_sizes() {
    update_option('thumbnail_size_w', 0);
    update_option('thumbnail_size_h', 0);
    update_option('medium_size_w', 0);
    update_option('medium_size_h', 0);
    update_option('medium_large_size_w', 0);
    update_option('medium_large_size_h', 0);
    update_option('large_size_w', 0);
    update_option('large_size_h', 0);
}
add_action('init', 'disable_default_image_sizes');


//размеры изображений
add_image_size('small', 500, 0, false);  // ширина 500px, высота автоматически
add_image_size('medium', 800, 0, false); // ширина 800px, высота автоматически
add_image_size('large', 1080, 0, false); // ширина 1080px, высота автоматически
add_image_size('xlarge', 1600, 0, false); // ширина 1600px, высота автоматически
add_image_size('full', 1800, 0, false);  // ширина 1800px, высота автоматически


//страница опций
if( function_exists('acf_add_options_page') ) {
    acf_add_options_page();
}


//убрать конструктор блоков со страницы
function remove_editor_from_home() {
    if (is_admin()) {
        $post_id = isset($_GET['post']) ? $_GET['post'] : (isset($_POST['post_ID']) ? $_POST['post_ID'] : false);
        if ($post_id) {
            $template_file = get_post_meta($post_id, '_wp_page_template', true);
            if ($template_file == 'about.php' || $template_file == 'home.php') { // замените на ваш шаблон
                remove_post_type_support('page', 'editor');
                remove_post_type_support('page', 'thumbnail');
            }
        }
    }
}
add_action('init', 'remove_editor_from_home');

//Возвращаем старый редактор
add_filter( 'use_block_editor_for_post_type', '__return_false', 100 );

// Разрешаем загрузку SVG файлов
function allow_svg_upload($mimes) {
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
}
add_filter('upload_mimes', 'allow_svg_upload');

// Защита от потенциальных угроз в SVG файлах
function fix_svg() {
    echo '<style type="text/css">
        .attachment-266x266, .thumbnail img {
             width: 100% !important;
             height: auto !important;
        }
        </style>';
}
add_action('admin_head', 'fix_svg');

// Отключение комментариев на страницах и записях
function disable_comments_post_types_support() {
    $post_types = get_post_types();
    foreach ($post_types as $post_type) {
        if (post_type_supports($post_type, 'comments')) {
            remove_post_type_support($post_type, 'comments');
            remove_post_type_support($post_type, 'trackbacks');
        }
    }
}
add_action('admin_init', 'disable_comments_post_types_support');

// Закрытие существующих комментариев
function disable_comments_status() {
    return false;
}
add_filter('comments_open', 'disable_comments_status', 20, 2);
add_filter('pings_open', 'disable_comments_status', 20, 2);

// Удаление пункта "Комментарии" из меню административной панели
function remove_comments_menu() {
    remove_menu_page('edit-comments.php');
}
add_action('admin_menu', 'remove_comments_menu');


//телега
function handle_form_submission() {
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['Phone'])) {
        require get_template_directory() . '/telegram.php';
        exit;
    }
}
add_action('template_redirect', 'handle_form_submission');


//номера страны
function enqueue_intl_tel_input() {
    // Подключение стилей
    wp_enqueue_style('intl-tel-input-css', 'https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/css/intlTelInput.min.css');

    // Подключение скриптов
    wp_enqueue_script('intl-tel-input-js', 'https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/js/intlTelInput.min.js', array('jquery'), null, true);

    // Если вам нужно подключить утилиты для валидации, вы можете сделать это здесь
    wp_enqueue_script('intl-tel-input-utils-js', 'https://cdnjs.cloudflare.com/ajax/libs/intl-tel-input/17.0.8/lib/libphonenumber.js', array('intl-tel-input-js'), null, true);
}

// Подключаем функции к нужному хуку
add_action('wp_enqueue_scripts', 'enqueue_intl_tel_input');


// Функция для форматирования номера телефона
function format_phone_number($phone) {
    // Удаляем все символы, кроме цифр
    $digits = preg_replace('/\D/', '', $phone);
    
    // Форматируем номер
    if (strlen($digits) === 12) { // Проверяем, что номер состоит из 12 цифр
        return '+' . substr($digits, 0, 3) . ' ' . substr($digits, 3, 3) . ' ' . substr($digits, 6, 3) . ' ' . substr($digits, 9);
    }
    
    return $phone;
}

?>